@@ -46,6 +46,9 @@ def getDynamicDomain():
 
 @app.command()
 def install(
+    reinstall: bool = typer.Option(
+        False, "--reinstall", "-r", help="Uninstall backplane first"
+    ),
     domain: str = typer.Option(
         getDynamicDomain(), "--domain", "-d", help="The domain your backplane runs on"
     ),
@@ -70,6 +73,9 @@ def install(
     error = False
     ssh_defaults = 'no-port-forwarding,no-X11-forwarding,no-agent-forwarding,no-pty,command="/usr/local/bin/backplane-ssh"'
 
+    if reinstall:
+        uninstall(force=True)
+
     # backplane['config_dir']
     if not os.path.exists(backplane["config_dir"]):
         if backplane["verbosity"] > 0:
@@ -344,6 +350,9 @@ def update():
         )
 
         typer.secho(f"Successfully updated backplane", err=False, fg=typer.colors.GREEN)
+
+        stop()
+        start()
     except Exception as e:
         typer.secho(f"Failed to update backplane: {e}", err=True, fg=typer.colors.RED)
 
@@ -492,7 +501,7 @@ def stop(
             docker_compose_command = f"docker-compose -f docker-compose.yml -p backplane-{service} down -v --rmi all --remove-orphans"
         else:
             docker_compose_command = (
-                f"docker-compose -f docker-compose.yml -p backplane-{service} stop"
+                f"docker-compose -f docker-compose.yml -p backplane-{service} down"
             )
         project_dir = os.path.join(
             backplane["active_context_dir"], service, backplane["environment"]
